Module graphite — Inmanta 2017.2.1 documentation

# Module graphite

> - License: Apache 2.0
> - Version: 0.5.1
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/graphite.git

## Entities

entity `graphite::Carbon`

  Parents: `ip::services::Server`

  Collect metrics and store them

  relation graphite::Frontend `graphite_frontend` [0:1]

    other end: `graphite::Frontend.carbon_server [1]`

  The following implementations are defined for this entity:

  > - `graphite::carbonServerRedhat`
  > - `graphite::carbonServerUbuntu`

  The following implements statements select implementations for this entity:

  > - `graphite::carbonServerRedhat` constraint `std::familyof(host.os,'redhat')`
  > - `graphite::carbonServerUbuntu` constraint `std::familyof(host.os,'ubuntu')`

entity `graphite::Frontend`

  Parents: `web::Application`

  relation graphite::Carbon `carbon_server` [1]

    other end: `graphite::Carbon.graphite_frontend [0:1]`

  The following implementations are defined for this entity:

  > - `graphite::graphiteWeb`

  The following implements statements select implementations for this entity:

  > - `graphite::graphiteWeb`

## Implementations

implementation `graphite::carbonServerRedhat`

implementation `graphite::carbonServerUbuntu`

implementation `graphite::graphiteWeb`